"use strict";

require("core-js/modules/es.promise.js");

const md5 = require('js-md5');

const localData = {
  data: {},
  setItem: function setItem(key, value) {
    this.data[key] = value;
  },
  clear: function clear() {
    this.data = {};
  },
  getItem: function getItem(key) {
    return this.data[key];
  },
  removeItem: function removeItem(key) {
    this.data[key] = null;
  }
};

const getStorage = () => {
  if (!window.localStorage) {
    return localData;
  } else {
    return window.localStorage;
  }
};

const TimeUnit = {
  SECONDS: 'SECONDS',
  MINUTES: 'MINUTES',
  HOURS: 'HOURS',
  DAYS: 'DAYS'
};
const LocalTimeUnit = {
  SECONDS: 1000,
  MINUTES: 1000 * 60,
  HOURS: 1000 * 60 * 60,
  DAYS: 1000 * 60 * 60 * 24
};

const removeItem = key => {
  if (typeof key !== 'string') {
    key = JSON.stringify(key);
  }

  getStorage().removeItem(md5(key));
};

const saveStartTime = startTime => {
  if (getStartTime() > parseInt("".concat(startTime || '0'))) {
    return;
  }

  getStorage().setItem('startTime', startTime);
};

const getStartTime = () => {
  return parseInt(getStorage().getItem('startTime') || '0');
};

const saveData = config => {
  if (config && config.key && config.url && config.data) {
    const url = config.url;
    const key = config.key;
    const cache = {
      url,
      key,
      persistent: config.persistent,
      startTime: getStartTime(),
      expires: !config.persistent ? new Date().getTime() + (config.expires || 3) * LocalTimeUnit[config.timeUnit || 'SECONDS'] : 0,
      data: config.data
    };
    getStorage().setItem(key, JSON.stringify(cache));
  }
};

const expires = () => {
  const storage = getStorage();

  for (const key in storage) {
    const item = storage.getItem(key);

    if (!item) {
      continue;
    }

    const cache = JSON.parse(item);

    if (!cache.persistent && cache.expires < new Date().getTime()) {
      getStorage().removeItem(key);
    }
  }
};

const getData = (key, callback) => {
  const cache = JSON.parse(getStorage().getItem(key));

  if (cache) {
    if (cache.startTime < getStartTime()) {
      getStorage().removeItem(key);
      return;
    }

    if (cache.persistent || cache.expires >= new Date().getTime()) {
      return new Promise(function (resolve, reject) {
        if (callback) {
          callback(cache.data);
        }

        resolve(cache.data);
      });
    }

    getStorage().removeItem(key);
  }
};

module.exports = () => {
  setInterval(expires, LocalTimeUnit.MINUTES);
  return {
    saveData,
    getData,
    saveStartTime,
    removeItem
  };
};
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.saveCacheByUrl = saveCacheByUrl;
exports.getCacheByUrl = getCacheByUrl;

require("core-js/modules/es.promise.js");

require("core-js/modules/es.object.assign.js");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const axios = require('axios');

const md5 = require('js-md5');

const {
  saveData,
  saveStartTime,
  getData
} = require('./cache')();

const timeoutUrl = {};

function saveCacheByUrl(value, data, urls) {
  const url = value.url || value;
  const config = urls[url] || {};

  if (config) {
    config.url = url;
    config.key = md5(JSON.stringify(value));
    config.data = {
      data
    };
    saveData(config);
  }
}

function getCacheByUrl(value, urls) {
  const config = urls[value.url] || {};

  if (config) {
    const data = getData(md5(JSON.stringify(value)));
    return data;
  }
}

const requestByCache = _ref => {
  let {
    config,
    request,
    urls
  } = _ref;
  const md = md5(JSON.stringify(config));

  if (timeoutUrl[md]) {
    if (!timeoutUrl[md].data) {
      return new Promise((resolve, reject) => {
        reject('正在加载数据，请等待！！');
      });
    } else {
      delete timeoutUrl[md];
    }
  }

  timeoutUrl[md] = {};
  return (getCacheByUrl(config, urls) || request(config).then(response => {
    saveStartTime(response.headers['start-time']);
    saveCacheByUrl(config, response.data, urls);
    return response;
  })).then(response => {
    timeoutUrl[md].data = response.data;
    return response;
  }, error => {
    delete timeoutUrl[md];
    return error;
  }).catch(() => delete timeoutUrl[md]);
};

module.exports = _ref2 => {
  let {
    baseURL,
    timeout = 5000,
    tokenKey = 'Authorization',
    urls,
    requestInterceptor = () => {},
    getToken = () => {}
  } = _ref2;
  const request = axios.create({
    baseURL,
    timeout
  });
  request.interceptors.request.use(_ref3 => {
    let config = Object.assign({}, _ref3);
    requestInterceptor(config);
    config.headers[tokenKey] = getToken();
    return config;
  }, error => {
    throw error;
  });
  request.interceptors.response.use(response => response, error => {
    const rejectObject = {
      error,
      type: 'error',
      message: '未定义的错误。'
    };

    if (!error.response) {
      rejectObject.message = '网络异常，请稍后刷新重试！';
      rejectObject.code = '1001';
    } else if (error.response.status === 401 || error.response.status === 403) {
      rejectObject.message = '无权访问！';
      rejectObject.code = '1002';
      rejectObject.type = 'low.power';
    } else {
      if (error.response.status === 502) {
        rejectObject.message = '网络繁忙，请稍候重试！';
      } else if (error.response && error.response.data && error.response.data.message) {
        rejectObject.message = error.response.data.message;
      } else if (error.message) {
        rejectObject.message = error.message;
      }
    }

    return Promise.reject(rejectObject);
  });
  return {
    request,

    finds(config) {
      if (urls) {
        return requestByCache({
          config,
          request,
          urls
        });
      } else {
        return request(config);
      }
    },

    post(config) {
      request(_objectSpread(_objectSpread({}, config), {}, {
        method: 'post'
      }));
    },

    put(config) {
      request(_objectSpread(_objectSpread({}, config), {}, {
        method: 'put'
      }));
    },

    del(config) {
      request(_objectSpread(_objectSpread({}, config), {}, {
        method: 'delete'
      }));
    },

    get(config) {
      request(_objectSpread(_objectSpread({}, config), {}, {
        method: 'get'
      }));
    },

    getCacheData: getData,
    saveCacheData: saveData
  };
};
